@@ -1,6 +1,6 @@
 names = ["Jair", ["Alice", "Yuting", "Ya"]]
 
-def print_lol(the_list, level):
+def print_lol(the_list, level = 0):
 	for each_item in the_list:
 		if(isinstance(each_item, list)):
 			print_lol(each_item, level + 1)
@@ -10,3 +10,5 @@ def print_lol(the_list, level):
 			print(each_item)
 
 print_lol(names, 0)
+print_lol(names)
+print_lol(names, 2)
